@@ -2,10 +2,12 @@
 from __future__ import annotations
 
 import sys
-from json import dump as jdump, loads as _jloads
+from json import dump as _jdump, dumps as _jdumps, loads as _jloads
 from json.decoder import JSONDecodeError
 
-from nestedtext import dump as ntdump, load as ntload
+from nestedtext import dump as _ntdump, dumps as _ntdumps, load as ntload
+from rich.console import Console as RichConsole
+from rich.syntax import Syntax as RichSyntax
 from yamlpath.common import Parsers as YPParsers
 
 from .casters import cast_stringy_data
@@ -15,7 +17,7 @@ from .converters import (
 
 try:
     from tomli import load as tload, loads as tloads
-    from tomli_w import dumps as tdumps
+    from tomli_w import dumps as _tdumps
 except ImportError:
     TOML_SUPPORT = False
 else:
@@ -26,6 +28,71 @@ YAML_EDITOR.indent(mapping=2, sequence=4, offset=2)
 ydump = YAML_EDITOR.dump
 yload = YAML_EDITOR.load
 
+RICH = RichConsole()
+
+
+def _syntax_print(content: str, syntax: str, console: RichConsole = RICH):
+    """
+    Print a syntax-highlighted rendering of the content to terminal.
+
+    Args:
+        content: Any code to be syntax-highlighted.
+        syntax: A syntax name recognized by pygments (via rich).
+        console: An initialized Rich Console object used to print with.
+    """
+    console.print(RichSyntax(content, syntax, theme='ansi_dark'))
+
+
+def ntdump(data: dict | list):
+    """
+    Pretty-print the data as NestedText, with color if interactive, to stdout.
+
+    Args:
+        data: A ``dict`` or ``list`` to dump as NestedText.
+    """
+    if sys.stdout.isatty():
+        _syntax_print(_ntdumps(data, indent=2), 'nt')
+    else:
+        _ntdump(data, sys.stdout, indent=2)
+
+
+def jdump(data: dict | list):
+    """
+    Pretty-print the data as JSON, with color if interactive, to stdout.
+
+    Args:
+        data: A ``dict`` or ``list`` to dump as JSON.
+    """
+    if sys.stdout.isatty():
+        _syntax_print(_jdumps(data, indent=2), 'json')
+    else:
+        _jdump(data, sys.stdout, indent=2)
+
+
+def _require_toml_support():
+    """
+    If TOML support is not installed, raise an exception.
+
+    Raises:
+        ImportError: The libraries for TOML support are absent.
+    """
+    if not TOML_SUPPORT:
+        raise ImportError("TOML support for nt2 is not installed. Try reinstalling as 'nt2[toml]'")
+
+
+def tdump(data: dict):
+    """
+    Pretty-print the data as TOML, with color if interactive, to stdout.
+
+    Args:
+        data: A ``dict`` to dump as TOML.
+    """
+    _require_toml_support()
+    if sys.stdout.isatty():
+        _syntax_print(_tdumps(data, multiline_strings=True), 'toml')
+    else:
+        print(_tdumps(data, multiline_strings=True), end='')
+
 
 def jloads(content: str) -> dict | list:
     """
@@ -53,11 +120,8 @@ def dump_json_to_nestedtext(*input_files):
     """
     # We may need to use a converter.unstructure here; We'll see.
     for f in input_files or (sys.stdin,):
-
-        content = f.read()
-        typed_data = jloads(content)
-
-        ntdump(typed_data, sys.stdout, indent=2)
+        typed_data = jloads(f.read())
+        ntdump(typed_data)
 
 
 def dump_yaml_to_nestedtext(*input_files):
@@ -72,24 +136,13 @@ def dump_yaml_to_nestedtext(*input_files):
     if not input_files:
         data = yload(sys.stdin)
         data = converter.unstructure(data)
-        ntdump(data, sys.stdout, indent=2)
+        ntdump(data)
     else:
         for f in input_files:
             with open(f) as ifile:
                 data = yload(ifile)
             data = converter.unstructure(data)
-            ntdump(data, sys.stdout, indent=2)
-
-
-def _require_toml_support():
-    """
-    If TOML support is not installed, raise an exception.
-
-    Raises:
-        ImportError: The libraries for TOML support are absent.
-    """
-    if not TOML_SUPPORT:
-        raise ImportError("TOML support for nt2 is not installed. Try reinstalling as 'nt2[toml]'")
+            ntdump(data)
 
 
 def dump_toml_to_nestedtext(*input_files):
@@ -105,13 +158,13 @@ def dump_toml_to_nestedtext(*input_files):
     if not input_files:
         data = tloads(sys.stdin.read())
         data = converter.unstructure(data)
-        ntdump(data, sys.stdout, indent=2)
+        ntdump(data)
     else:
         for f in input_files:
             with open(f, 'rb') as ifile:
                 data = tload(ifile)
             data = converter.unstructure(data)
-            ntdump(data, sys.stdout, indent=2)
+            ntdump(data)
 
 
 def dump_nestedtext_to_yaml(
@@ -165,7 +218,7 @@ def dump_nestedtext_to_toml(*input_files, bool_paths=(), num_paths=(), date_path
         )
         if isinstance(data, list):
             data = {'TOML does not allow top-level arrays': data}
-        print(tdumps(data, multiline_strings=True), end='')
+        tdump(data)
 
 
 def dump_nestedtext_to_json(*input_files, bool_paths=(), null_paths=(), num_paths=()):
@@ -188,4 +241,4 @@ def dump_nestedtext_to_json(*input_files, bool_paths=(), null_paths=(), num_path
             num_paths=num_paths,
             converter=mk_json_types_converter(),
         )
-        jdump(data, sys.stdout, indent=2)
+        jdump(data)
